@@ -651,6 +651,51 @@ class Base(Controller):
             from ..ext.github import dir_diff
             pp(dir_diff(self.app.pargs.url))
 
+
+    @ex(
+        help='Manage TODOs using Google Keep',
+        arguments=[
+            (['action'],{
+                "help" : "One of {add, ls, dn}",
+                "action": "store"
+            }),
+            (['-t'],{
+                "help": "Text of the TODO",
+                "action": "store"
+            }),
+            # (['-l'],{
+            #     "help": "Length of time in hours this is expected to take",
+            #     "action": "store"
+            # }),
+            (['-p'],{
+                "help" : "Project id. Daily is 0",
+                "action" : 'store'
+            }),
+            (['-i'],{
+                "help" : "Id of the finished task",
+                "action": "store"
+            }),
+            (['-f'],{
+                "help" : "Filter TODOs for ls",
+                "action": "store"
+            })
+        ]
+    )
+    def td(self):
+        from ..ext.asana import add_todo, asana_list_todos, done_todo
+        project = int(self.app.pargs.p or 0)
+
+        if self.app.pargs.action=='add':
+            add_todo(self.app.pargs.t, project)
+        elif self.app.pargs.action=='ls':
+            asana_list_todos(self.app.pargs.f or True,
+                       self.app.pargs.p)
+        elif self.app.pargs.action=='dn':
+            done_todo(self.app.pargs.i)
+
+        else:
+            raise NotImplemented("Action must be one of {add, ls, dn}")
+
     @ex(
         help='Manage TODOs using Google Keep',
         arguments=[
@@ -680,7 +725,7 @@ class Base(Controller):
             })
         ]
     )
-    def td(self):
+    def gkeep(self):
         from ..ext.gkeep import add_todo, list_todos, done_todo
         project = self.app.pargs.p or 'SL'
 
