@@ -66,8 +66,12 @@ def dir_diff(cwd: str, action = 'status') -> json:
 
     diff_df = pd.DataFrame(output, columns=['dir',action])
     if action == 'status':
-        # remove if up to date
+        # remove if up to master
         diff_df = diff_df[~diff_df.status.str.contains('On branch master')]
+        
+        # remove if main
+        diff_df = diff_df[~diff_df.status.str.contains('On branch main')]
+        
         # drop rows with empty ('') status
         diff_df = diff_df[diff_df.status != '']
         
